/**
* The MIT License (MIT)
* 
* Copyright (c) 2013 Retroswitch LLC
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*
*/

//
// Includes

#include "ConnectDialog.h"
#include "SettingsManager.h"
#include <QtGui>

//
// ConnectDialog Methods

/******************************************************************************/
/* Constructor                                                                */
/******************************************************************************/

ConnectDialog::ConnectDialog( QWidget* parent, Qt::WFlags flags ) :
    QDialog( parent, flags )
{
    m_ui.setupUi( this );
    
    connect( this, SIGNAL( accepted() ), this, SLOT( OnAccepted() ) );

    m_ui.host->setText( SettingsManager::GetInstance()->GetPreferredHost() );
    m_ui.port->setText( tr( "%1" ).arg( SettingsManager::GetInstance()->GetPreferredPort() ) );
    m_ui.port->setEnabled( false ); // todo: allow port configuration on server
}

/******************************************************************************/
/* Destructor                                                                 */
/******************************************************************************/

ConnectDialog::~ConnectDialog()
{
}

/******************************************************************************/
/* OnAccepted                                                                 */
/******************************************************************************/

void ConnectDialog::OnAccepted()
{
    SettingsManager::GetInstance()->SetPreferredHost( m_ui.host->text() );
    SettingsManager::GetInstance()->SetPreferredPort( m_ui.port->text().toUShort() );
}
