/**
* The MIT License (MIT)
* 
* Copyright (c) 2013 Retroswitch LLC
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*
*/

//
// Includes

#include "ProfileManager.h"

//
// ProfileManager Methods

/******************************************************************************/
/* GetInstance                                                                */
/******************************************************************************/

ProfileManager* ProfileManager::GetInstance()
{
    static ProfileManager s_profile_manager;
    return( &s_profile_manager );
}

/******************************************************************************/
/* Constructor                                                                */
/******************************************************************************/

ProfileManager::ProfileManager()
{
    Profile* p;

    // PET (40 Column)

    p = new Profile;

    p->m_rows = 25;
    p->m_columns = 40;
    p->m_pixelAspect = .74f;
    p->m_supportsScreenColor = false;
    p->m_scanlineGap = true;
    p->m_colors.push_back( QColor( "#000000" ) );
    p->m_colors.push_back( QColor( "#00ff00" ) );

    m_profiles.push_back( p );

    // PET (80 Column)

    p = new Profile;

    p->m_rows = 25;
    p->m_columns = 80;
    p->m_pixelAspect = .37f;
    p->m_supportsScreenColor = false;
    p->m_scanlineGap = true;
    p->m_colors.push_back( QColor( "#000000" ) );
    p->m_colors.push_back( QColor( "#00ff00" ) );

    m_profiles.push_back( p );

    // Vic-20    

    p = new Profile;

    p->m_rows = 23;
    p->m_columns = 22;
    p->m_pixelAspect = 1.6f;
    p->m_supportsScreenColor = true;
    p->m_scanlineGap = false;
    p->m_colors.push_back( QColor( "#000000" ) );
    p->m_colors.push_back( QColor( "#ffffff" ) );
    p->m_colors.push_back( QColor( "#941701" ) );
    p->m_colors.push_back( QColor( "#52c6d4" ) );
    p->m_colors.push_back( QColor( "#901ccc" ) );
    p->m_colors.push_back( QColor( "#51be08" ) );
    p->m_colors.push_back( QColor( "#311ad5" ) );
    p->m_colors.push_back( QColor( "#c4d71c" ) );

    m_profiles.push_back( p );
    
    // Commodore 64

    p = new Profile;

    p->m_rows = 25;
    p->m_columns = 40;
    p->m_pixelAspect = .74f;
    p->m_supportsScreenColor = true;
    p->m_scanlineGap = false;
    p->m_colors.push_back( QColor( "#000000" ) );
    p->m_colors.push_back( QColor( "#ffffff" ) );
    p->m_colors.push_back( QColor( "#894036" ) );
    p->m_colors.push_back( QColor( "#7abfc7" ) );
    p->m_colors.push_back( QColor( "#8a46ae" ) );
    p->m_colors.push_back( QColor( "#68a941" ) );
    p->m_colors.push_back( QColor( "#3e31a2" ) );
    p->m_colors.push_back( QColor( "#d0dc71" ) );
    p->m_colors.push_back( QColor( "#905f25" ) );
    p->m_colors.push_back( QColor( "#5c4700" ) );
    p->m_colors.push_back( QColor( "#bb776d" ) );
    p->m_colors.push_back( QColor( "#555555" ) );
    p->m_colors.push_back( QColor( "#808080" ) );
    p->m_colors.push_back( QColor( "#acea88" ) );
    p->m_colors.push_back( QColor( "#7c70da" ) );
    p->m_colors.push_back( QColor( "#ababab" ) );

    m_profiles.push_back( p );
}

/******************************************************************************/
/* Destructor                                                                 */
/******************************************************************************/

ProfileManager::~ProfileManager()
{
    while( !m_profiles.isEmpty() )
    {
        delete m_profiles.takeFirst();
    }
}
