/**
* The MIT License (MIT)
* 
* Copyright (c) 2013 Retroswitch LLC
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*
*/

#ifndef _SETTINGSMANAGER_H
#define _SETTINGSMANAGER_H

//
// Includes

#include "Types.h"
#include <QString>

//
// Forward Declarations

//
// SettingsManager Class

class SettingsManager
{
public:

    // --- Singleton ---

    static SettingsManager* GetInstance();

public:

                            // Get/set the preferred host to connect to.
                            // This is managed by the connection dialog.
    const QString&          GetPreferredHost() const;
    void                    SetPreferredHost( const QString& host );

                            // Get/set the preferred port to connect to.
                            // This is managed by the connection dialog.
    uint16                  GetPreferredPort() const;
    void                    SetPreferredPort( uint16 port );

private:

    // --- Private Types ---

    // --- Private Methods ---

                            SettingsManager();
                           ~SettingsManager();

    // --- Private Members ---

    QString                 m_preferredHost;
    uint16                  m_preferredPort;

};

//
// SettingsManager Inline Methods

/******************************************************************************/
/* GetPreferredHost                                                           */
/******************************************************************************/

inline const QString& SettingsManager::GetPreferredHost() const
{
    return( m_preferredHost );
}

/******************************************************************************/
/* SetPreferredHost                                                           */
/******************************************************************************/

inline void SettingsManager::SetPreferredHost( const QString& host )
{
    m_preferredHost = host;
}

/******************************************************************************/
/* GetPreferredPort                                                           */
/******************************************************************************/

inline uint16 SettingsManager::GetPreferredPort() const
{
    return( m_preferredPort );
}

/******************************************************************************/
/* SetPreferredPort                                                           */
/******************************************************************************/

inline void SettingsManager::SetPreferredPort( uint16 port )
{
    m_preferredPort = port;
}

//
//

#endif // _SETTINGSMANAGER_H