/**
* The MIT License (MIT)
* 
* Copyright (c) 2013 Retroswitch LLC
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*
*/

#ifndef _FLYER_H
#define _FLYER_H

//
// Includes

#include "Types.h"

//
// Forward Declarations

//
// Functions

        // Prepares the Flyer for communication. This should be called before
        // any other Flyer*() functions are called.
        // Returns 0 if successful, else -1 (Flyer not attached?).
int8    FlyerStartup();

        // End communication with the Flyer. This should be called before program
        // exit. No Flyer*() functions should be called beyond this point.
void    FlyerShutdown();

        // Verify the Flyer has the specified firmware version (or later) installed.
        // Returns 1 if the required firmware is installed, 0 if not.
int8    FlyerRequireFirmware( const char* version );

        // Opens the specified network channel on the Flyer for listening.
        // Returns 0 if successful, else -1 if an error occurred.  
int8    FlyerListen( uint8 channel, uint16 port );

        // Gets connection information for the specified channel. If a connection has
        // been established, remoteIp and remotePort will be updated with information
        // about the remote connection.
        // Returns 0 if not connected, 1 if connected, else -1 if an error occurred.
int8    FlyerGetConnection( uint8 channel, uint8 remoteIp[4], uint16* remotePort );

        // Gets bytes available for reading on the specified channel. Returns -1 if
        // there is no active connection.
        // This can also be used to detect initial connection status: >=0 indicates
        // an established connection.
int     FlyerGetBytesAvailable( uint8 channel );

        // Gets the Flyer's current IP address.
        // Returns 0 if successful, else -1 if an error occurred.
int8    FlyerGetIpAddress( uint8 flyerIp[4] );

//
//

#endif // _FLYER_H