/**
* The MIT License (MIT)
* 
* Copyright (c) 2013 Retroswitch LLC
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*
*/

//
// Includes

#include "../Display.h"
#include <conio.h>
#include <string.h>

//
// Defines & Macros

#define DISPLAY_WIDTH 40
#define DISPLAY_HEIGHT 25
#define COLOR_ADDR ((uint8*)0xd800)
#define CHARACTER_ADDR ((uint8*)0x400)

//
// Local Data

static uint8 sStatusBackup[2][DISPLAY_WIDTH];
static uint8 sBorderColor;
static uint8 sBackgroundColor;

//
// Functions

/******************************************************************************/
/* DisplayStartup                                                             */
/******************************************************************************/

void DisplayStartup()
{
    DisplaySetBorderColor( sBorderColor );
    DisplaySetBackgroundColor( sBackgroundColor );
    DisplayClear();
}

/******************************************************************************/
/* DisplayShutdown                                                            */
/******************************************************************************/

void DisplayShutdown()
{
    memset( COLOR_ADDR, 14, 1000 );
    *((uint8*)0xd020) = 14;
    *((uint8*)0xd021) = 6;
    clrscr();
}

/******************************************************************************/
/* DisplayStatusEnable                                                        */
/******************************************************************************/

void DisplayStatusEnable( const char* line1, const char* line2 )
{
    uint8 i;
    uint8 status_color = sBackgroundColor ? 0 : 1;
    uint8 old_color;

    for( i=0; i<DISPLAY_WIDTH; i++ )
    {
        sStatusBackup[0][i] = DisplayGetCell( i, 0 );
        sStatusBackup[1][i] = DisplayGetCell( i, 1 );
    }

    memset( COLOR_ADDR, status_color, 80 );
    memset( CHARACTER_ADDR, 0xa0, 80 );

    revers( 1 );
    old_color = textcolor( status_color );    
    cputsxy( 0, 0, line1 );
    cputsxy( 0, 1, line2 );
    textcolor( old_color );
    revers( 0 );
}

/******************************************************************************/
/* DisplayStatusDisable                                                       */
/******************************************************************************/

void DisplayStatusDisable()
{
    uint8 i;

    for( i=0; i<DISPLAY_WIDTH; i++ )
    {
        DisplaySetCell( i, 0, sStatusBackup[0][i] );
        DisplaySetCell( i, 1, sStatusBackup[1][i] );
    }
}

/******************************************************************************/
/* DisplayClear                                                               */
/******************************************************************************/

void DisplayClear()
{
    memset( COLOR_ADDR, 0, 1000 );
    memset( CHARACTER_ADDR, 0x20, 1000 );
}

/******************************************************************************/
/* DisplayGetWidth                                                            */
/******************************************************************************/

uint8 DisplayGetWidth()
{
    return( DISPLAY_WIDTH );
}

/******************************************************************************/
/* DisplayGetHeight                                                           */
/******************************************************************************/

uint8 DisplayGetHeight()
{
    return( DISPLAY_HEIGHT );
}

/******************************************************************************/
/* DisplayGetBorderColor                                                      */
/******************************************************************************/

uint8 DisplayGetBorderColor()
{
    return( sBorderColor );
}

/******************************************************************************/
/* DisplaySetBorderColor                                                      */
/******************************************************************************/

void DisplaySetBorderColor( uint8 color )
{
    *((uint8*)0xd020) = sBorderColor = color;
}

/******************************************************************************/
/* DisplayGetBackgroundColor                                                  */
/******************************************************************************/

uint8 DisplayGetBackgroundColor()
{
    return( sBackgroundColor );
}

/******************************************************************************/
/* DisplaySetBackgroundColor                                                  */
/******************************************************************************/

void DisplaySetBackgroundColor( uint8 color )
{
    *((uint8*)0xd021) = sBackgroundColor = color;
}

/******************************************************************************/
/* DisplayGetCell                                                             */
/******************************************************************************/

uint8 DisplayGetCell( int x, int y )
{
    int offset = y * DISPLAY_WIDTH + x;

    if( CHARACTER_ADDR[offset] != 0x20 )
    {
        return( COLOR_ADDR[offset] & 0xf );
    }

    return( 0xff );
}

/******************************************************************************/
/* DisplaySetCell                                                             */
/******************************************************************************/

void DisplaySetCell( int x, int y, uint8 color )
{
    int offset = y * DISPLAY_WIDTH + x;

    COLOR_ADDR[offset] = color & 0xf;
    CHARACTER_ADDR[offset] = (color == 0xff) ? 0x20 : 0xa0;
}
